EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Applications_PurgeDeployableData',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Purges a deployable and all its associations from the system.'
GO

IF OBJECT_ID('[Applications_PurgeDeployableData]') IS NOT NULL DROP PROCEDURE [Applications_PurgeDeployableData]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Applications_PurgeDeployableData]
(
	@Deployable_Id INT
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @ConfigurationFiles TABLE ([ConfigurationFile_Id] INT NOT NULL)
    INSERT INTO @ConfigurationFiles ([ConfigurationFile_Id])
    SELECT [ConfigurationFile_Id]
      FROM [ConfigurationFiles]
     WHERE [Deployable_Id] = @Deployable_Id

	DECLARE @DatabaseChangeScripts TABLE ([Script_Id] INT NOT NULL)
    INSERT INTO @DatabaseChangeScripts ([Script_Id])
    SELECT [Script_Id]
      FROM [DatabaseChangeScripts]
     WHERE [Deployable_Id] = @Deployable_Id

    DELETE [DeployableDependencies]
     WHERE [Deployable_Id] = @Deployable_Id
	    OR [DependsOn_Deployable_Id] = @Deployable_Id

	DELETE [DeployablesImported]
	 WHERE [Deployable_Id] = @Deployable_Id

	DELETE
      FROM [BuildArtifacts]
     WHERE [Deployable_Id] = @Deployable_Id

	DELETE
      FROM [ConfigurationFileDeployments]
     WHERE [ConfigurationFile_Id] IN ( SELECT [ConfigurationFile_Id] FROM @ConfigurationFiles )

    DELETE
      FROM [ReleaseConfigurationFiles]
     WHERE [ConfigurationFile_Id] IN ( SELECT [ConfigurationFile_Id] FROM @ConfigurationFiles )

	DELETE
      FROM [ConfigurationFileVersions]
     WHERE [ConfigurationFile_Id] IN ( SELECT [ConfigurationFile_Id] FROM @ConfigurationFiles )


	DELETE
      FROM [ConfigurationFileInstances]
     WHERE [ConfigurationFile_Id] IN ( SELECT [ConfigurationFile_Id] FROM @ConfigurationFiles )


	DELETE
      FROM [ConfigurationFiles]
     WHERE [ConfigurationFile_Id] IN ( SELECT [ConfigurationFile_Id] FROM @ConfigurationFiles )


	DELETE
      FROM [DatabaseChangeScripts]
     WHERE [Deployable_Id] = @Deployable_Id

	DELETE 
      FROM [ReleaseDeployables]
     WHERE [Deployable_Id] = @Deployable_Id 
	 

	DECLARE @Deployable_Name SQL_VARIANT, @Application_Id INT
	 SELECT @Deployable_Name = [Deployable_Name] 
	       ,@Application_Id = [Application_Id] 
       FROM [Deployables] 
      WHERE [Deployable_Id] = @Deployable_Id

	DELETE 
      FROM [Deployables]
     WHERE [Deployable_Id] = @Deployable_Id 

	/* Raise Event */
	EXEC [Events_RaiseEvent] 'APPDLD',@Application_Id,@Deployable_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Applications_PurgeDeployableData] TO [BuildMasterUser_Role]
