EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_CreateOrUpdateManualAction',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ManualAction_Sequence',
    /* Description_Text        */ 'Creates a new manual action or marks an existing one as complete.'
GO

IF OBJECT_ID('[Executions_CreateOrUpdateManualAction]') IS NOT NULL DROP PROCEDURE [Executions_CreateOrUpdateManualAction]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_CreateOrUpdateManualAction]
(
	@Execution_Id INT,
	@CompletedBy_User_Name USERNAME = NULL,
	@AssignedTo_Principal_Name USERNAME = NULL,
	@Task_Name VARCHAR(50),
	@Task_Description TEXT = NULL,
	@ManualAction_Sequence INT = NULL OUT
)
AS
BEGIN


SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @ManualAction_Sequence IS NULL
	BEGIN

		SET @ManualAction_Sequence = COALESCE((SELECT MAX([ManualAction_Sequence])
		                                         FROM [ManualActionsInProgress]
												WHERE [Execution_Id] = @Execution_Id), 0) + 1

		INSERT INTO [ManualActionsInProgress]
		(
			[Execution_Id],
            [ManualAction_Sequence],
			[Task_Name],
			[Task_Description],
			[AssignedTo_Principal_Name],
			[ActionStarted_Date]
		)
		VALUES
		(
			@Execution_Id,
            @ManualAction_Sequence,
			@Task_Name,
			@Task_Description,
			@AssignedTo_Principal_Name,
			GETUTCDATE()
		)

	END

	IF @CompletedBy_User_Name IS NOT NULL
	BEGIN

		UPDATE [ManualActionsInProgress]
		   SET [CompletedBy_User_Name] = @CompletedBy_User_Name
		 WHERE [Execution_Id] = @Execution_Id
		   AND [ManualAction_Sequence] = @ManualAction_Sequence

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Executions_CreateOrUpdateManualAction] TO [BuildMasterUser_Role]
